"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from writer import utils

class ContentDetectorResponseLabel(str, Enum):
    FAKE = 'fake'
    REAL = 'real'


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class ContentDetectorResponse:
    label: ContentDetectorResponseLabel = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('label') }})
    score: float = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('score') }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from writer import utils

class GenerationModelInfoResponseType(str, Enum):
    GPT = 'GPT'
    INSTRUCT = 'Instruct'


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class GenerationModelInfoResponse:
    id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id') }})
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    type: GenerationModelInfoResponseType = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Any, Optional
from writer import utils

class ContentIssueService(str, Enum):
    COMMON_MISTAKES = 'common-mistakes'
    BANNED_WORDS = 'banned-words'
    DICTIONARY = 'dictionary'
    GEC = 'gec'
    INFINITIVE = 'infinitive'
    SPELLING = 'spelling'
    WRITING_STYLE = 'writing-style'
    CUSTOM_RULES = 'custom-rules'
    SENTENCE_CASE = 'sentence-case'
    ACRONYM = 'acronym'
    OXFORD_COMMA = 'oxford-comma'
    ML_PUNCTUATION = 'ml-punctuation'
    EMOJIS = 'emojis'
    GENDER_PRONOUNS = 'gender-pronouns'
    SENSITIVITY = 'sensitivity'
    PLAGIARISM = 'plagiarism'
    READABILITY = 'readability'
    SENTENCE_COMPLEXITY = 'sentence-complexity'
    VOCABULARY = 'vocabulary'
    PARAGRAPH_LENGTH = 'paragraph-length'
    PLAIN_LANGUAGE = 'plain-language'
    HEALTHY_COMMN = 'healthy-commn'
    CONFIDENCE = 'confidence'
    DATA_LOSS_PREVENTION = 'data-loss-prevention'
    HATE_SPEECH = 'hate-speech'
    CONTENT_SAFEGUARDS = 'content-safeguards'
    FEEDBACK = 'feedback'
    CLAIM = 'claim'
    QUOTE = 'quote'
    GENDER_NOUNS = 'gender-nouns'
    GENDER_TONE = 'gender-tone'
    GRAMMAR = 'grammar'
    PUNCTUATION_DARK = 'punctuation-dark'
    FORMATTING = 'formatting'
    TWITTER = 'twitter'
    GEC_DARK = 'gec-dark'
    GEC_GPT3 = 'gec-gpt3'


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class ContentIssue:
    from_: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('from') }})
    service: ContentIssueService = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('service') }})
    until: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('until') }})
    description: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('description'), 'exclude': lambda f: f is None }})
    meta: Optional[Any] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('meta'), 'exclude': lambda f: f is None }})
    suggestions: Optional[list[str]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('suggestions'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .approvedtermextension import *
from .approvedtermextensioncreate import *
from .briefdocument import *
from .briefdocuments import *
from .completiongenerationchoice import *
from .completiongenerationchoicelogprobs import *
from .completionrequest import *
from .completionresponse import *
from .contentdetectorrequest import *
from .contentdetectorresponse import *
from .contentissue import *
from .contentrequest import *
from .contentsettings import *
from .correctionresponse import *
from .createcustomizationrequest import *
from .createtermsrequest import *
from .createtermsresponse import *
from .customizationsresponse import *
from .deleteresponse import *
from .document import *
from .draft import *
from .failmessage import *
from .failresponse import *
from .fulllinkedterm import *
from .fulltermwithuser import *
from .generatetemplaterequest import *
from .generationmodelinforesponse import *
from .generationmodelsresponse import *
from .hyperparameters import *
from .input import *
from .linkedtermcreate import *
from .magicrequestinput import *
from .metadata import *
from .modelcustomization import *
from .modelfile import *
from .modelfilesresponse import *
from .pagepublicapiresponse import *
from .pagewithsectionresponse import *
from .paginatedresult_fulltermwithuser import *
from .paginatedresult_pagepublicapiresponse import *
from .paginatedresult_snippetwithuser import *
from .paginatedresult_userpublicresponse import *
from .pagination import *
from .processedcontent import *
from .sectioninfo import *
from .security import *
from .simpleuser import *
from .snippettagv2 import *
from .snippetupdate import *
from .snippetwithuser import *
from .subscriptionpublicresponseapi import *
from .templatedetailsresponse import *
from .termcreate import *
from .termexample import *
from .termexamplecreate import *
from .terminologyuser import *
from .termmistake import *
from .termmistakecreate import *
from .termtagcreate import *
from .termtagresponse import *
from .termupdate import *
from .updatetermsrequest import *
from .uploadmodelfilerequest import *
from .usage import *
from .usageitem import *
from .userpublicresponse import *

__all__ = ["ApprovedTermExtension","ApprovedTermExtensionCreate","BriefDocument","BriefDocumentAccess","BriefDocuments","CompletionGenerationChoice","CompletionGenerationChoiceLogprobs","CompletionRequest","CompletionResponse","ContentDetectorRequest","ContentDetectorResponse","ContentDetectorResponseLabel","ContentIssue","ContentIssueService","ContentRequest","ContentSettings","CorrectionResponse","CreateCustomizationRequest","CreateTermsRequest","CreateTermsRequestFailHandling","CreateTermsResponse","CustomizationsResponse","DeleteResponse","Document","DocumentAccess","Draft","FailMessage","FailResponse","FullLinkedTerm","FullLinkedTermPos","FullTermWithUser","FullTermWithUserPos","FullTermWithUserType","GenerateTemplateRequest","GenerationModelInfoResponse","GenerationModelInfoResponseType","GenerationModelsResponse","HyperParameters","Input","InputType","LinkedTermCreate","MagicRequestInput","MetaData","MetaDataTier","ModelCustomization","ModelFile","ModelFilesResponse","PagePublicAPIResponse","PagePublicAPIResponseStatus","PageWithSectionResponse","PageWithSectionResponseStatus","PaginatedResultFullTermWithUser","PaginatedResultPagePublicAPIResponse","PaginatedResultSnippetWithUser","PaginatedResultUserPublicResponse","Pagination","ProcessedContent","SectionInfo","Security","SimpleUser","SnippetTagV2","SnippetUpdate","SnippetWithUser","SubscriptionPublicResponseAPI","SubscriptionPublicResponseAPIProductName","SubscriptionPublicResponseAPIStatus","TemplateDetailsResponse","TermCreate","TermCreatePos","TermCreateType","TermExample","TermExampleCreate","TermExampleCreateType","TermExampleType","TermMistake","TermMistakeCreate","TermMistakeCreatePos","TermMistakePos","TermTagCreate","TermTagResponse","TermUpdate","TermUpdatePos","TermUpdateType","TerminologyUser","UpdateTermsRequest","UpdateTermsRequestFailHandling","UploadModelFileRequest","UploadModelFileRequestFile","Usage","UsageItem","UserPublicResponse","UserPublicResponseAccountStatus"]



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import deleteresponse as shared_deleteresponse
from ..shared import failresponse as shared_failresponse
from typing import Optional



@dataclasses.dataclass
class DeleteTermsRequest:
    team_id: int = dataclasses.field(metadata={'path_param': { 'field_name': 'teamId', 'style': 'simple', 'explode': False }})
    ids: Optional[list[int]] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'ids', 'style': 'form', 'explode': True }})
    organization_id: Optional[int] = dataclasses.field(default=None, metadata={'path_param': { 'field_name': 'organizationId', 'style': 'simple', 'explode': False }})
    x_request_id: Optional[str] = dataclasses.field(default=None, metadata={'header': { 'field_name': 'X-Request-ID', 'style': 'simple', 'explode': False }})
    




@dataclasses.dataclass
class DeleteTermsResponse:
    content_type: str = dataclasses.field()
    status_code: int = dataclasses.field()
    delete_response: Optional[shared_deleteresponse.DeleteResponse] = dataclasses.field(default=None)
    fail_response: Optional[shared_failresponse.FailResponse] = dataclasses.field(default=None)
    r"""Bad Request"""
    headers: Optional[dict[str, list[str]]] = dataclasses.field(default=None)
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from ..shared import input as shared_input
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from marshmallow import fields
from typing import Optional
from writer import utils


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class TemplateDetailsResponse:
    category_id: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('categoryId') }})
    creation_time: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('creationTime'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id') }})
    modification_time: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('modificationTime'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    description: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('description'), 'exclude': lambda f: f is None }})
    guide_url: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('guideUrl'), 'exclude': lambda f: f is None }})
    inputs: Optional[list[shared_input.Input]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('inputs'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional
from writer import utils

class InputType(str, Enum):
    TEXTBOX = 'textbox'
    TEXTAREA = 'textarea'
    DROPDOWN = 'dropdown'


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class Input:
    dynamic: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('dynamic') }})
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    required: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('required') }})
    type: InputType = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    help: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('help'), 'exclude': lambda f: f is None }})
    max_fields: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('maxFields'), 'exclude': lambda f: f is None }})
    min_fields: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('minFields'), 'exclude': lambda f: f is None }})
    options: Optional[list[str]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('options'), 'exclude': lambda f: f is None }})
    subtitle: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('subtitle'), 'exclude': lambda f: f is None }})
    unit_copy: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('unitCopy'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .sdkconfiguration import SDKConfiguration
from typing import Optional
from writer import utils
from writer.models import errors, operations, shared

class Content:
    r"""Methods related to Content"""
    sdk_configuration: SDKConfiguration

    def __init__(self, sdk_config: SDKConfiguration) -> None:
        self.sdk_configuration = sdk_config
        
    
    def check(self, content_request: shared.ContentRequest, team_id: int, organization_id: Optional[int] = None) -> operations.ContentCheckResponse:
        r"""Check your content against your preset styleguide."""
        request = operations.ContentCheckRequest(
            content_request=content_request,
            team_id=team_id,
            organization_id=organization_id,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(operations.ContentCheckRequest, base_url, '/content/organization/{organizationId}/team/{teamId}/check', request, self.sdk_configuration.globals)
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "content_request", 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        if data is None and form is None:
            raise Exception('request body is required')
        headers['Accept'] = 'application/json;q=1, application/json;q=0'
        headers['user-agent'] = f'speakeasy-sdk/{self.sdk_configuration.language} {self.sdk_configuration.sdk_version} {self.sdk_configuration.gen_version} {self.sdk_configuration.openapi_doc_version}'
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.ContentCheckResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            res.headers = http_res.headers
            
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.ProcessedContent])
                res.processed_content = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)
        elif http_res.status_code in [400, 401, 403, 404, 500]:
            res.headers = http_res.headers
            
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.FailResponse])
                res.fail_response = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def correct(self, content_request: shared.ContentRequest, team_id: int, x_request_id: Optional[str] = None, organization_id: Optional[int] = None) -> operations.ContentCorrectResponse:
        r"""Apply the style guide suggestions directly to your content."""
        request = operations.ContentCorrectRequest(
            content_request=content_request,
            team_id=team_id,
            x_request_id=x_request_id,
            organization_id=organization_id,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(operations.ContentCorrectRequest, base_url, '/content/organization/{organizationId}/team/{teamId}/correct', request, self.sdk_configuration.globals)
        headers = utils.get_headers(request)
        req_content_type, data, form = utils.serialize_request_body(request, "content_request", 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        if data is None and form is None:
            raise Exception('request body is required')
        headers['Accept'] = 'application/json;q=1, application/json;q=0'
        headers['user-agent'] = f'speakeasy-sdk/{self.sdk_configuration.language} {self.sdk_configuration.sdk_version} {self.sdk_configuration.gen_version} {self.sdk_configuration.openapi_doc_version}'
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.ContentCorrectResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            res.headers = http_res.headers
            
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.CorrectionResponse])
                res.correction_response = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)
        elif http_res.status_code in [400, 401, 403, 404, 500]:
            res.headers = http_res.headers
            
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.FailResponse])
                res.fail_response = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from typing import Optional
from writer import utils


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class CompletionRequest:
    prompt: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('prompt') }})
    best_of: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('bestOf'), 'exclude': lambda f: f is None }})
    frequency_penalty: Optional[float] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('frequencyPenalty'), 'exclude': lambda f: f is None }})
    logprobs: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('logprobs'), 'exclude': lambda f: f is None }})
    max_tokens: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('maxTokens'), 'exclude': lambda f: f is None }})
    min_tokens: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('minTokens'), 'exclude': lambda f: f is None }})
    n: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('n'), 'exclude': lambda f: f is None }})
    presence_penalty: Optional[float] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('presencePenalty'), 'exclude': lambda f: f is None }})
    stop: Optional[list[str]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('stop'), 'exclude': lambda f: f is None }})
    temperature: Optional[float] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('temperature'), 'exclude': lambda f: f is None }})
    top_p: Optional[float] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('topP'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from ..shared import metadata as shared_metadata
from ..shared import usage as shared_usage
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from enum import Enum
from marshmallow import fields
from writer import utils

class SubscriptionPublicResponseAPIProductName(str, Enum):
    FREE = 'free'
    PRO = 'pro'
    TEAM = 'team'
    ENTERPRISE = 'enterprise'
    LEGACY = 'legacy'

class SubscriptionPublicResponseAPIStatus(str, Enum):
    TRIALING = 'trialing'
    ACTIVE = 'active'
    PAST_DUE = 'past_due'
    INCOMPLETE = 'incomplete'
    INCOMPLETE_EXPIRED = 'incomplete_expired'
    UNPAID = 'unpaid'
    CANCELED = 'canceled'


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class SubscriptionPublicResponseAPI:
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('createdAt'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    meta: shared_metadata.MetaData = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('meta') }})
    product_name: SubscriptionPublicResponseAPIProductName = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('productName') }})
    seats: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('seats') }})
    status: SubscriptionPublicResponseAPIStatus = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status') }})
    subscription_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('subscriptionId') }})
    usage: shared_usage.Usage = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('usage') }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import requests
from dataclasses import dataclass, field
from typing import Any

SERVERS = [
    'https://enterprise-api.writer.com',
]
"""Contains the list of servers available to the SDK"""

@dataclass
class SDKConfiguration:
    client: requests.Session
    security_client: requests.Session
    server_url: str = ''
    server_idx: int = 0
    globals: dict[str, dict[str, dict[str, Any]]] = field(default_factory=dict)
    language: str = 'python'
    openapi_doc_version: str = '1.7'
    sdk_version: str = '0.14.0'
    gen_version: str = '2.70.0'

    def get_server_details(self) -> tuple[str, dict[str, str]]:
        if self.server_url:
            return self.server_url.removesuffix('/'), {}
        if self.server_idx is None:
            self.server_idx = 0

        return SERVERS[self.server_idx], {}



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import failresponse as shared_failresponse
from typing import Optional



@dataclasses.dataclass
class DeleteModelCustomizationRequest:
    customization_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'customizationId', 'style': 'simple', 'explode': False }})
    model_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'modelId', 'style': 'simple', 'explode': False }})
    organization_id: Optional[int] = dataclasses.field(default=None, metadata={'path_param': { 'field_name': 'organizationId', 'style': 'simple', 'explode': False }})
    




@dataclasses.dataclass
class DeleteModelCustomization200ApplicationJSON:
    pass



@dataclasses.dataclass
class DeleteModelCustomizationResponse:
    content_type: str = dataclasses.field()
    status_code: int = dataclasses.field()
    delete_model_customization_200_application_json_object: Optional[DeleteModelCustomization200ApplicationJSON] = dataclasses.field(default=None)
    fail_response: Optional[shared_failresponse.FailResponse] = dataclasses.field(default=None)
    r"""Bad Request"""
    headers: Optional[dict[str, list[str]]] = dataclasses.field(default=None)
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    

